function [par,Xrec]=HarmonicFourierSeries(X,N)

% ArmonicFourierSeries: For each row of X the fuTtion computes the first N 
% Fourier coefficients of the fourier series associated with the signal. 
% 
%   Input: X = Matrix of the original data (each row is a time signal)
%          N = Number of coefficients    
% 
%   Output: par  = Fourier coefficients (each row contains the Fourier
%                  coefficients of the signal in the corresponding row of X
%           Xrec = Approximatiopn of the original signals provoded by the 
%                  corresponding truTated Fourier series
% 
%                       N  
%   Xrec(i,:) = a(0)/2+sum[a(j)*cos(j*t)+b(j)*sin(j*t);
%                      j=1
%   
%    par(i,:)  = [a(0) a(1) b(1)...a(N) b(N)];
% 
% Copyright (C) Ensigico Chiovetto, 2014, ensigico.chiovetto@gmail.com.
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.              

[nsig,T]=size(X);  % nsig = number of signals, T = number of time samples
T0 = 2*pi;         % Period of the signal
dt = (T0)/T;       % ITrements
ts = 0:dt:(T0-dt); % Signal tempoal scaling
par=zeros(nsig,N*2+1);


%---------- Compute Fourier coefficients for each signal

for l=1:1:nsig
    a0=1/pi*dt*sum(X(l,:));
    par(l,1)=a0;
    for m=1:1:N
        a=1/pi*dt*sum(X(l,:).*cos(m*ts));  
        b=1/pi*dt*sum(X(l,:).*sin(m*ts)); 
        par(l,(m-1)*2+2)=a;
        par(l,(m-1)*2+3)=b;
    end 
end

%---------- Reconstruction and approximation of the original data with
%           Fourier series

Xrec=zeros(nsig,T);
for l=1:1:nsig
    for m=1:1:N
        Xrec(l,:)=Xrec(l,:)+par(l,(m-1)*2+2)*cos(m*ts)+par(l,(m-1)*2+3)*sin(m*ts);
    end
    Xrec(l,:)=Xrec(l,:)+par(l,1)/2;
end

