function[A,B,p]=NNMF(X,NumS,maxiter)

% Implement non-negative matrix factorisation (NMF) algorithm by Lee and
% Seung (1999). Nature.
%
%  min E(X,AB), A>=0, B>=0
%
%  Usage:
%     [A,B]=NMF(X,NumS);
%     [A,B]=NMF(X,NumS,maxiter);
%
% ------------------------------------------------------------------------
% Input:
%
%           X    :   non-negative m x n data matrix
%          NumS  :   number of sources to extract
%        maxiter :   maximal number of updates for A and B
%          opts  :   options structure
%
% Output:
%         A      :    m  x NumS non-negative weight matrix
%         B      :  NumS x  n   non-negative source matrix
%
% Copyright (C) Enrico Chiovetto, 2014, enrico.chiovetto@gmail.com.
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this software for your research, please refer to the paper
% entitled " ",
% by Chiovetto E, d'Avella A and Giese, MA.

[m,n]=size(X);
if nargin <3
    maxiter = 250;
end

%----------  Initialize A and B

A=rand(m,NumS)+1; % +1 to avoid 0 as inital value
B=rand(NumS,n)+1; % +1 to avoid 0 as inital value

%--------------------------------------------------------------------------

for iter=1:maxiter
    A = ((A'+10^-4).*(B*X'./(B*B'*A'+10^-5)))';
    B = (B+10^-4).*(A'*X./(A'*A*B+10^-5));
    p(iter)=1-norm(X-A*B,'fro')^2/norm(X-repmat(mean(X,2),1,n),'fro')^2;
end

%---------- Make sure output is positive
A=max(A,0);
B=max(B,0);

