function [c,ceq,gradc,gradceq]=nonlinconModSNM3F(x, phaseS, ts)

% nonlinconModS computes nonlinear inequality constraints. It imposes the 
% synergies to be non-negative during the identification of the Fourier 
% module of trh space-by-time primitives.
%
% Copyright (C) Enrico Chiovetto, 2014, enrico.chiovetto@gmail.com.
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this software for your research, please refer to the paper
% entitled " ",
% by Chiovetto E, d'Avella A and Giese, MA.


x=x';
[NumS,NumA]=size(squeezeOne(phaseS(1,:,:)));
modS=reshape(x,NumA+1,NumS)';
T=numel(ts);

S=modS(:,2:NumA+1).*exp(1i*squeezeOne(phaseS(1,:,:)));
Sour=repmat(modS(:,1),1,numel(ts));
for l=1:1:NumS
    for m=1:1:NumA
        Sour(l,:)=Sour(l,:)+conj(S(l,m))*exp(-1i*m*ts)+S(l,m)*exp(1i*m*ts);
    end
end

ceq=[];
c=[];
for k=1:1:NumS
    c=[c; -Sour(k,:)'];
end
if nargout > 2
    SS=exp(1i*squeezeOne(phaseS(1,:,:)));
    gradc = zeros(NumS*T,NumS*(NumA+1));
    for l=1:1:NumS
        gradc((l-1)*T+1:l*T,(l-1)*(NumA+1)+1)=ones(T,1);
        for m=1:1:NumA
            gradc((l-1)*T+1:l*T,(l-1)*(NumA+1)+m+1)=-2*cos(m*ts+phaseS(1,l,m))';
        end
    end
   gradc=gradc';
   gradceq = [];
end