function num_harmonics=setNumA(X, T, sim_lev)

% setNumA determines the mininum number of harmonics to approximate a data
% matrix X with a a minimum level of similarity sim_lev. 
%
% Input:
%
%         X    :  Data matrix. X can have two sizes. It can be a matrix 
%                 with time signals of the same trial piled vertically and 
%                 signals of different trials concatenated horizontally. 
%                 X will  have in thic case size (NumM) x (NumT x T). Or it
%                 ca have 

%         T    :   number of time samples of each standardized signal
%      sim_lev :   level of desired similarity (0 - 1)
%         
% Output:
%         Rec :   reconstructed mixture of the scaled and shifted sources
%                  size(NumM,NumT*T)
%
%Copyright (C) Enrico Chiovetto, 2014, enrico.chiovetto@gmail.com.
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this software for your research, please refer to the paper
% entitled " ",
% by Chiovetto E, d'Avella A and Giese, MA.

if or(sim_lev<0,sim_lev>1)
    error('Invalid sim_lev value. sim_lev has to range between 0 and 1.');
end

[~,m] = size(X);

R=zeros(1,(floor(T/2)-rem(T,2)));

for k=1:1:(floor(T/2)-rem(T,2))
    if m==T
        [~,rec]=HarmonicFourierSeries(X,k);
        R(k)=1-norm(X-rec)^2/norm(X-repmat(mean(X,2),1,T))^2;
    else
        Xr=reshape(X',T,numel(X)/T)';
        [~,rec]=HarmonicFourierSeries(Xr,k);
        R(k)=1-norm(Xr-rec)^2/norm(Xr-repmat(mean(Xr,2),1,T))^2;
    end
end

num_harmonics = find(R>sim_lev,1);
if isempty(num_harmonics)
    num_harmonics = floor(T/2)-rem(T,2);
end