function Rec=tv_syn_mix(syn, W, Tau)

% TV_syn_mix builds a mixture of the delayed and scaled TV synergies
%
%  Usage:
%     Rec=syn_mix(syn, W, Tau)
%
% =========================================================================
% Input:
%
%         Syn  :   real NumM x NumS x N source matrix  
%         W    :   real NumT x NumS weight matrix 
%         Tau  :   real NumT x NumS delay matrix 
%         
% Output:
%         Rec :   reconstructed mixture of the scaled and shifted sources
%                  size(NumM,NumT*T)
%
%==========================================================================
% 
% Copyright (C) Enrico Chiovetto, 2014, enrico.chiovetto@gmail.com.
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% If you use this software for your research, please refer to the paper
% entitled " ", 
% by Chiovetto E, d'Avella A and Giese, MA.

if nargin < 3 
    error('The function needs three input arguments');
end

[NumM,NumS,N]=size(syn);   % size of the syn
[NumT]=size(W,1);     % sixe of the W matrix
T=N;
Fs=N/T;
dF = Fs/N;                      
Rec=zeros(NumM,T*NumT);

% Combination in Fourier space

for k=1:1:NumT
    for j=1:1:NumM
        X=fft(squeezeOne(syn(j,:,:)),[],2);
        if rem(T,2)==0
            Y=X.*exp(-1j*2*pi*(repmat([0:floor(N/2) -floor(N/2)+1:-1],NumS,1))*dF.*repmat(Tau(k,:)',1,N));
        else
            Y=X.*exp(-1j*2*pi*(repmat([0:floor(N/2) -floor(N/2):-1],NumS,1))*dF.*repmat(Tau(k,:)',1,N));
        end
        y=real(ifft(Y,[],2));
        Rec(j,(k-1)*T+1:k*T)=W(k,:)*y;
    end
end



